@@ -26,29 +26,30 @@ FlatButton::FlatButton(QWidget *parent)
     : QPushButton(parent)
 {
     setFlat(true);
-    static const QString defaultStyle = QStringLiteral("text-align:left; color:black");
-    setStyleSheet(defaultStyle);
+    static const QString default_style = QStringLiteral("text-align:left");
+    setStyleSheet(default_style);
 }
 
 FlatButton::FlatButton(const QString &name, QWidget *parent)
     : QPushButton(name, parent)
 {
     setFlat(true);
-    static const QString namedStyle = QStringLiteral("text-align:left");
-    setStyleSheet(namedStyle);
+    static const QString named_style = QStringLiteral("text-align:left");
+    setStyleSheet(named_style);
 }
 
 void FlatButton::leaveEvent(QEvent *e)
 {
-    static const QString leaveStyle = QStringLiteral("text-align:left; text-decoration:none");
-    setStyleSheet(leaveStyle);
+    static const QString leave_style = QStringLiteral("text-align:left; text-decoration:none");
+    setStyleSheet(leave_style);
     QPushButton::leaveEvent(e);
 }
 
 void FlatButton::enterEvent(QEnterEvent *e)
 {
-    static const QString enterStyle = QStringLiteral("QPushButton { text-align:left; text-decoration:underline}; QToolTip { text-decoration: none; }");
-    setStyleSheet(enterStyle);
+    static const QString enter_style
+        = QStringLiteral("QPushButton { text-align:left; text-decoration:underline}; QToolTip { text-decoration: none; }");
+    setStyleSheet(enter_style);
     QPushButton::enterEvent(e);
 }
 
