@@ -37,6 +37,6 @@ public:
     void setIconSize(QSize);
 
 protected:
-    void enterEvent(QEnterEvent *e);
-    void leaveEvent(QEvent *e);
+    void enterEvent(QEnterEvent *e) override;
+    void leaveEvent(QEvent *e) override;
 };
